LIBRARY DSDP
VERSION 5.8
EXPORTS
DSDPCreate
DSDPSetup
DSDPSolve
DSDPComputeX
DSDPComputeAndFactorS
DSDPDestroy
DSDPCreateBCone
BConeAllocateBounds
BConeSetLowerBound
BConeSetUpperBound
BConeSetPSlackVariable
BConeSetPSurplusVariable
BConeScaleBarrier
BConeView
BConeSetXArray
BConeCopyX
DSDPBoundDualVariables
DSDPSetYBounds
DSDPGetYBounds
DSDPCreateLPCone
LPConeSetData
LPConeSetData2
LPConeGetData
LPConeScaleBarrier
LPConeGetXArray
LPConeGetSArray
LPConeGetDimension
LPConeView
LPConeView2
LPConeCopyS
DSDPCreateSDPCone
SDPConeSetBlockSize
SDPConeGetBlockSize
SDPConeSetStorageFormat
SDPConeGetStorageFormat
SDPConeCheckStorageFormat
SDPConeSetSparsity
SDPConeView
SDPConeView2
SDPConeView3
SDPConeSetASparseVecMat
SDPConeSetADenseVecMat
SDPConeSetARankOneMat
SDPConeSetConstantMat
SDPConeSetZeroMat
SDPConeSetIdentity
SDPConeViewDataMatrix
SDPConeMatrixView
SDPConeAddASparseVecMat
SDPConeAddADenseVecMat
SDPConeAddConstantMat
SDPConeAddIdentity
SDPConeAddARankOneMat
SDPConeAddSparseVecMat
SDPConeAddDenseVecMat
SDPConeSetSparseVecMat
SDPConeSetDenseVecMat
SDPConeSetXMat
SDPConeSetXArray
SDPConeGetXArray
SDPConeRestoreXArray
SDPConeCheckData
SDPConeRemoveDataMatrix
SDPConeGetNumberOfBlocks
SDPConeComputeS
SDPConeComputeX
SDPConeAddADotX
SDPConeViewX
SDPConeScaleBarrier
SDPConeXVMultiply
SDPConeComputeXV
SDPConeAddXVAV
SDPConeUseLAPACKForDualMatrix
DSDPSetDualObjective
DSDPAddObjectiveConstant
DSDPGetDObjective
DSDPGetDDObjective
DSDPGetPObjective
DSDPGetPPObjective
DSDPGetDualityGap
DSDPGetScale
DSDPSetScale
DSDPGetPenaltyParameter
DSDPGetPenalty
DSDPCopyB
DSDPSetR0
DSDPGetR
DSDPSetRTolerance
DSDPGetRTolerance
DSDPSetY0
DSDPGetY
DSDPGetYMakeX
DSDPGetDYMakeX
DSDPGetMuMakeX
DSDPGetBarrierParameter
DSDPSetBarrierParameter
DSDPReuseMatrix
DSDPGetReuseMatrix
DSDPGetDimension
DSDPSetMaxIts
DSDPGetMaxIts
DSDPSetStepTolerance
DSDPGetStepTolerance
DSDPSetGapTolerance
DSDPGetGapTolerance
DSDPSetPNormTolerance
DSDPGetPNormTolerance
DSDPSetDualBound
DSDPGetDualBound
DSDPSetPTolerance
DSDPGetPTolerance
DSDPGetPInfeasibility
DSDPSetMaxTrustRadius
DSDPGetMaxTrustRadius
DSDPStopReason
DSDPGetSolutionType
DSDPSetPotentialParameter
DSDPGetPotentialParameter
DSDPUseDynamicRho
DSDPGetPotential
DSDPUseLAPACKForSchur
DSDPGetNumberOfVariables
DSDPGetFinalErrors
DSDPGetGapHistory
DSDPGetRHistory
DSDPGetIts
DSDPGetPnorm
DSDPGetStepLengths
DSDPSetMonitor
DSDPSetStandardMonitor
DSDPSetFileMonitor
DSDPSetPenaltyParameter
DSDPUsePenalty
DSDPGetTraceX
DSDPSetZBar
DSDPSetDualLowerBound
DSDPGetDataNorms
DSDPGetYMaxNorm
SDPConeUseFullSymmetricFormat
SDPConeUsePackedFormat
DSDPSetFixedVariable
DSDPSetFixedVariables
DSDPGetFixedYX
DSDPView
DSDPPrintOptions
DSDPPrintData
DSDPPrintSolution
DSDPSetOptions
DSDPReadOptions
DSDPSetDestroyRoutine
DSDPTime
DSDPLogInfoAllow
DSDPError
DSDPLogFInfo
DSDPFError
DSDPMemoryLog
DSDPEventLogBegin
DSDPEventLogEnd
DSDPEventLogRegister
DSDPEventLogInitialize
DSDPEventLogSummary
DSDPEventLogInitialize
dsdpoutputfile
DSDPSetConvergenceFlag
DSDPMMalloc
DSDPFFree
;; end of file ;;
